#-----------------------------------------------------------------------------
# Copyright (c) 2013-2020, PyInstaller Development Team.
#
# Distributed under the terms of the GNU General Public License (version 2
# or later) with exception for distributing the bootloader.
#
# The full license is in the file COPYING.txt, distributed with this software.
#
# SPDX-License-Identifier: (GPL-2.0-or-later WITH Bootloader-exception)
#-----------------------------------------------------------------------------


hiddenimports = ['sip',
                 'PyQt4.QtAssistant',
                 'PyQt4.QtCore',
                 'PyQt4.QtGui',
                 'PyQt4.QtNetwork',
                 'PyQt4.Qt3Support',
                 'PyQt4.QtSql',
                 'PyQt4.QtSvg',
                 'PyQt4.QtTest',
                 'PyQt4.QtSql',
                 'PyQt4.QtXml',
                 'PyQt4.QtWebKit',
                 'PyQt4.QtOpenGL',
                 ]
